==> zio-aws-datazone_2.13-7.21.15.5-sources.jar: zio/aws/datazone/model/GetDataSourceRunResponse.scala <==
package zio.aws.datazone.model
import zio.aws.datazone.model.primitives.{
  DataSourceId,
  ProjectId,
  DataSourceRunId,
  DomainId,
  DateTime
}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters._
final case class GetDataSourceRunResponse(
    createdAt: DateTime,
    dataSourceConfigurationSnapshot: Optional[String] = Optional.Absent,
    dataSourceId: DataSourceId,
    domainId: DomainId,
    errorMessage: Optional[zio.aws.datazone.model.DataSourceErrorMessage] =
      Optional.Absent,
    id: DataSourceRunId,
    projectId: ProjectId,
    runStatisticsForAssets: Optional[
      zio.aws.datazone.model.RunStatisticsForAssets
    ] = Optional.Absent,
    startedAt: Optional[DateTime] = Optional.Absent,
    status: zio.aws.datazone.model.DataSourceRunStatus,
    stoppedAt: Optional[DateTime] = Optional.Absent,
    `type`: zio.aws.datazone.model.DataSourceRunType,
    updatedAt: DateTime
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.datazone.model.GetDataSourceRunResponse = {
    import GetDataSourceRunResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.datazone.model.GetDataSourceRunResponse
      .builder()
      .createdAt(DateTime.unwrap(createdAt): Instant)
      .optionallyWith(
        dataSourceConfigurationSnapshot.map(value => value: java.lang.String)
      )(_.dataSourceConfigurationSnapshot)
      .dataSourceId(DataSourceId.unwrap(dataSourceId): java.lang.String)
      .domainId(DomainId.unwrap(domainId): java.lang.String)
      .optionallyWith(errorMessage.map(value => value.buildAwsValue()))(
        _.errorMessage
      )
      .id(DataSourceRunId.unwrap(id): java.lang.String)
      .projectId(ProjectId.unwrap(projectId): java.lang.String)
      .optionallyWith(
        runStatisticsForAssets.map(value => value.buildAwsValue())
      )(_.runStatisticsForAssets)
      .optionallyWith(startedAt.map(value => DateTime.unwrap(value): Instant))(
        _.startedAt
      )
      .status(status.unwrap)
      .optionallyWith(stoppedAt.map(value => DateTime.unwrap(value): Instant))(
        _.stoppedAt
      )
      .`type`(`type`.unwrap)
      .updatedAt(DateTime.unwrap(updatedAt): Instant)
      .build()
  }
  def asReadOnly: zio.aws.datazone.model.GetDataSourceRunResponse.ReadOnly =
    zio.aws.datazone.model.GetDataSourceRunResponse.wrap(buildAwsValue())
}
object GetDataSourceRunResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.datazone.model.GetDataSourceRunResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.datazone.model.GetDataSourceRunResponse =
      zio.aws.datazone.model.GetDataSourceRunResponse(
        createdAt,
        dataSourceConfigurationSnapshot.map(value => value),
        dataSourceId,
        domainId,
        errorMessage.map(value => value.asEditable),
        id,
        projectId,
        runStatisticsForAssets.map(value => value.asEditable),
        startedAt.map(value => value),
        status,
        stoppedAt.map(value => value),
        `type`,
        updatedAt
      )
    def createdAt: DateTime
    def dataSourceConfigurationSnapshot: Optional[String]
    def dataSourceId: DataSourceId
    def domainId: DomainId
    def errorMessage
        : Optional[zio.aws.datazone.model.DataSourceErrorMessage.ReadOnly]
    def id: DataSourceRunId
    def projectId: ProjectId
    def runStatisticsForAssets
        : Optional[zio.aws.datazone.model.RunStatisticsForAssets.ReadOnly]
    def startedAt: Optional[DateTime]
    def status: zio.aws.datazone.model.DataSourceRunStatus
    def stoppedAt: Optional[DateTime]
    def `type`: zio.aws.datazone.model.DataSourceRunType
    def updatedAt: DateTime
    def getCreatedAt: ZIO[Any, Nothing, DateTime] = ZIO.succeed(createdAt)
    def getDataSourceConfigurationSnapshot: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField(
        "dataSourceConfigurationSnapshot",
        dataSourceConfigurationSnapshot
      )
    def getDataSourceId: ZIO[Any, Nothing, DataSourceId] =
      ZIO.succeed(dataSourceId)
    def getDomainId: ZIO[Any, Nothing, DomainId] = ZIO.succeed(domainId)
    def getErrorMessage: ZIO[
      Any,
      AwsError,
      zio.aws.datazone.model.DataSourceErrorMessage.ReadOnly
    ] = AwsError.unwrapOptionField("errorMessage", errorMessage)
    def getId: ZIO[Any, Nothing, DataSourceRunId] = ZIO.succeed(id)
    def getProjectId: ZIO[Any, Nothing, ProjectId] = ZIO.succeed(projectId)
    def getRunStatisticsForAssets: ZIO[
      Any,
      AwsError,
      zio.aws.datazone.model.RunStatisticsForAssets.ReadOnly
    ] = AwsError.unwrapOptionField(
      "runStatisticsForAssets",
      runStatisticsForAssets
    )
    def getStartedAt: ZIO[Any, AwsError, DateTime] =
      AwsError.unwrapOptionField("startedAt", startedAt)
    def getStatus
        : ZIO[Any, Nothing, zio.aws.datazone.model.DataSourceRunStatus] =
      ZIO.succeed(status)
    def getStoppedAt: ZIO[Any, AwsError, DateTime] =
      AwsError.unwrapOptionField("stoppedAt", stoppedAt)
    def getType: ZIO[Any, Nothing, zio.aws.datazone.model.DataSourceRunType] =
      ZIO.succeed(`type`)
    def getUpdatedAt: ZIO[Any, Nothing, DateTime] = ZIO.succeed(updatedAt)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.datazone.model.GetDataSourceRunResponse
  ) extends zio.aws.datazone.model.GetDataSourceRunResponse.ReadOnly {
    override val createdAt: DateTime =
      zio.aws.datazone.model.primitives.DateTime(impl.createdAt())
    override val dataSourceConfigurationSnapshot: Optional[String] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dataSourceConfigurationSnapshot())
        .map(value => value: String)
    override val dataSourceId: DataSourceId =
      zio.aws.datazone.model.primitives.DataSourceId(impl.dataSourceId())
    override val domainId: DomainId =
      zio.aws.datazone.model.primitives.DomainId(impl.domainId())
    override val errorMessage
        : Optional[zio.aws.datazone.model.DataSourceErrorMessage.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.errorMessage())
        .map(value => zio.aws.datazone.model.DataSourceErrorMessage.wrap(value))
    override val id: DataSourceRunId =
      zio.aws.datazone.model.primitives.DataSourceRunId(impl.id())
    override val projectId: ProjectId =
      zio.aws.datazone.model.primitives.ProjectId(impl.projectId())
    override val runStatisticsForAssets
        : Optional[zio.aws.datazone.model.RunStatisticsForAssets.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.runStatisticsForAssets())
        .map(value => zio.aws.datazone.model.RunStatisticsForAssets.wrap(value))
    override val startedAt: Optional[DateTime] = zio.aws.core.internal
      .optionalFromNullable(impl.startedAt())
      .map(value => zio.aws.datazone.model.primitives.DateTime(value))
    override val status: zio.aws.datazone.model.DataSourceRunStatus =
      zio.aws.datazone.model.DataSourceRunStatus.wrap(impl.status())
    override val stoppedAt: Optional[DateTime] = zio.aws.core.internal
      .optionalFromNullable(impl.stoppedAt())
      .map(value => zio.aws.datazone.model.primitives.DateTime(value))
    override val `type`: zio.aws.datazone.model.DataSourceRunType =
      zio.aws.datazone.model.DataSourceRunType.wrap(impl.`type`())
    override val updatedAt: DateTime =
      zio.aws.datazone.model.primitives.DateTime(impl.updatedAt())
  }
  def wrap(
      impl: software.amazon.awssdk.services.datazone.model.GetDataSourceRunResponse
  ): zio.aws.datazone.model.GetDataSourceRunResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-datazone_3-7.21.15.11-sources.jar: zio/aws/datazone/model/GetDataSourceRunResponse.scala <==
package zio.aws.datazone.model
import zio.aws.datazone.model.primitives.{
  DataSourceId,
  ProjectId,
  DataSourceRunId,
  DomainId,
  DateTime
}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters.*
final case class GetDataSourceRunResponse(
    createdAt: DateTime,
    dataSourceConfigurationSnapshot: Optional[String] = Optional.Absent,
    dataSourceId: DataSourceId,
    domainId: DomainId,
    errorMessage: Optional[zio.aws.datazone.model.DataSourceErrorMessage] =
      Optional.Absent,
    id: DataSourceRunId,
    projectId: ProjectId,
    runStatisticsForAssets: Optional[
      zio.aws.datazone.model.RunStatisticsForAssets
    ] = Optional.Absent,
    startedAt: Optional[DateTime] = Optional.Absent,
    status: zio.aws.datazone.model.DataSourceRunStatus,
    stoppedAt: Optional[DateTime] = Optional.Absent,
    `type`: zio.aws.datazone.model.DataSourceRunType,
    updatedAt: DateTime
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.datazone.model.GetDataSourceRunResponse = {
    import GetDataSourceRunResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.datazone.model.GetDataSourceRunResponse
      .builder()
      .createdAt(DateTime.unwrap(createdAt): Instant)
      .optionallyWith(
        dataSourceConfigurationSnapshot.map(value => value: java.lang.String)
      )(_.dataSourceConfigurationSnapshot)
      .dataSourceId(DataSourceId.unwrap(dataSourceId): java.lang.String)
      .domainId(DomainId.unwrap(domainId): java.lang.String)
      .optionallyWith(errorMessage.map(value => value.buildAwsValue()))(
        _.errorMessage
      )
      .id(DataSourceRunId.unwrap(id): java.lang.String)
      .projectId(ProjectId.unwrap(projectId): java.lang.String)
      .optionallyWith(
        runStatisticsForAssets.map(value => value.buildAwsValue())
      )(_.runStatisticsForAssets)
      .optionallyWith(startedAt.map(value => DateTime.unwrap(value): Instant))(
        _.startedAt
      )
      .status(status.unwrap)
      .optionallyWith(stoppedAt.map(value => DateTime.unwrap(value): Instant))(
        _.stoppedAt
      )
      .`type`(`type`.unwrap)
      .updatedAt(DateTime.unwrap(updatedAt): Instant)
      .build()
  }
  def asReadOnly: zio.aws.datazone.model.GetDataSourceRunResponse.ReadOnly =
    zio.aws.datazone.model.GetDataSourceRunResponse.wrap(buildAwsValue())
}
object GetDataSourceRunResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.datazone.model.GetDataSourceRunResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.datazone.model.GetDataSourceRunResponse =
      zio.aws.datazone.model.GetDataSourceRunResponse(
        createdAt,
        dataSourceConfigurationSnapshot.map(value => value),
        dataSourceId,
        domainId,
        errorMessage.map(value => value.asEditable),
        id,
        projectId,
        runStatisticsForAssets.map(value => value.asEditable),
        startedAt.map(value => value),
        status,
        stoppedAt.map(value => value),
        `type`,
        updatedAt
      )
    def createdAt: DateTime
    def dataSourceConfigurationSnapshot: Optional[String]
    def dataSourceId: DataSourceId
    def domainId: DomainId
    def errorMessage
        : Optional[zio.aws.datazone.model.DataSourceErrorMessage.ReadOnly]
    def id: DataSourceRunId
    def projectId: ProjectId
    def runStatisticsForAssets
        : Optional[zio.aws.datazone.model.RunStatisticsForAssets.ReadOnly]
    def startedAt: Optional[DateTime]
    def status: zio.aws.datazone.model.DataSourceRunStatus
    def stoppedAt: Optional[DateTime]
    def `type`: zio.aws.datazone.model.DataSourceRunType
    def updatedAt: DateTime
    def getCreatedAt: ZIO[Any, Nothing, DateTime] = ZIO.succeed(createdAt)
    def getDataSourceConfigurationSnapshot: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField(
        "dataSourceConfigurationSnapshot",
        dataSourceConfigurationSnapshot
      )
    def getDataSourceId: ZIO[Any, Nothing, DataSourceId] =
      ZIO.succeed(dataSourceId)
    def getDomainId: ZIO[Any, Nothing, DomainId] = ZIO.succeed(domainId)
    def getErrorMessage: ZIO[
      Any,
      AwsError,
      zio.aws.datazone.model.DataSourceErrorMessage.ReadOnly
    ] = AwsError.unwrapOptionField("errorMessage", errorMessage)
    def getId: ZIO[Any, Nothing, DataSourceRunId] = ZIO.succeed(id)
    def getProjectId: ZIO[Any, Nothing, ProjectId] = ZIO.succeed(projectId)
    def getRunStatisticsForAssets: ZIO[
      Any,
      AwsError,
      zio.aws.datazone.model.RunStatisticsForAssets.ReadOnly
    ] = AwsError.unwrapOptionField(
      "runStatisticsForAssets",
      runStatisticsForAssets
    )
    def getStartedAt: ZIO[Any, AwsError, DateTime] =
      AwsError.unwrapOptionField("startedAt", startedAt)
    def getStatus
        : ZIO[Any, Nothing, zio.aws.datazone.model.DataSourceRunStatus] =
      ZIO.succeed(status)
    def getStoppedAt: ZIO[Any, AwsError, DateTime] =
      AwsError.unwrapOptionField("stoppedAt", stoppedAt)
    def getType: ZIO[Any, Nothing, zio.aws.datazone.model.DataSourceRunType] =
      ZIO.succeed(`type`)
    def getUpdatedAt: ZIO[Any, Nothing, DateTime] = ZIO.succeed(updatedAt)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.datazone.model.GetDataSourceRunResponse
  ) extends zio.aws.datazone.model.GetDataSourceRunResponse.ReadOnly {
    override val createdAt: DateTime =
      zio.aws.datazone.model.primitives.DateTime(impl.createdAt())
    override val dataSourceConfigurationSnapshot: Optional[String] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dataSourceConfigurationSnapshot())
        .map(value => value: String)
    override val dataSourceId: DataSourceId =
      zio.aws.datazone.model.primitives.DataSourceId(impl.dataSourceId())
    override val domainId: DomainId =
      zio.aws.datazone.model.primitives.DomainId(impl.domainId())
    override val errorMessage
        : Optional[zio.aws.datazone.model.DataSourceErrorMessage.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.errorMessage())
        .map(value => zio.aws.datazone.model.DataSourceErrorMessage.wrap(value))
    override val id: DataSourceRunId =
      zio.aws.datazone.model.primitives.DataSourceRunId(impl.id())
    override val projectId: ProjectId =
      zio.aws.datazone.model.primitives.ProjectId(impl.projectId())
    override val runStatisticsForAssets
        : Optional[zio.aws.datazone.model.RunStatisticsForAssets.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.runStatisticsForAssets())
        .map(value => zio.aws.datazone.model.RunStatisticsForAssets.wrap(value))
    override val startedAt: Optional[DateTime] = zio.aws.core.internal
      .optionalFromNullable(impl.startedAt())
      .map(value => zio.aws.datazone.model.primitives.DateTime(value))
    override val status: zio.aws.datazone.model.DataSourceRunStatus =
      zio.aws.datazone.model.DataSourceRunStatus.wrap(impl.status())
    override val stoppedAt: Optional[DateTime] = zio.aws.core.internal
      .optionalFromNullable(impl.stoppedAt())
      .map(value => zio.aws.datazone.model.primitives.DateTime(value))
    override val `type`: zio.aws.datazone.model.DataSourceRunType =
      zio.aws.datazone.model.DataSourceRunType.wrap(impl.`type`())
    override val updatedAt: DateTime =
      zio.aws.datazone.model.primitives.DateTime(impl.updatedAt())
  }
  def wrap(
      impl: software.amazon.awssdk.services.datazone.model.GetDataSourceRunResponse
  ): zio.aws.datazone.model.GetDataSourceRunResponse.ReadOnly = new Wrapper(
    impl
  )
}
